#!/bin/bash
# Retreives Hijack source and patches, then applies the patches.
# Requires: wget, printrange (requires perl in path);
#
# I assume if you're compiling kernels you already have bunzip2, tar, zcat and patch

BASEVER="300"; # The base version to patch from. Version that has the full source tree archive
LASTPATCH="340"; # The highest current patch level

PRINTRANGE="./printrange"; # location of the printrange program
BASEURL="http://empeg-hijack.sourceforge.net"; # Base URL for source/patch files
BASESRCFILE="v${BASEVER}.tar.bz2"; # The full source archive we are patching from
RELPATCHDIR="patches/relative"; # Relative location of relative patches on the web site

# Put the base source archive URL into a file named hijackurls
echo ${BASEURL}/${BASESRCFILE}>hijackurls;
# Put all the source patches' URLs into hijackurls
for i in `$PRINTRANGE $((BASEVER + 1))-${LASTPATCH}` ; do 
  PATCHFILE="v$((i - 1))-v${i}.patch.gz";
  echo ${BASEURL}/${RELPATCHDIR}/${PATCHFILE}>>hijackurls;
done;

# Tell wget to retreive all URLs from the file (-c will do HTTP range/resume)
wget -c -i hijackurls;
rm hijackurls;

# Untar the base source archive
bunzip2 -c ${BASESRCFILE} | tar -xf -;

cd "v${BASEVER}";
# Run the patches in order
zcat `ls ../v*.patch.gz | sort -n` | patch -p1

echo "Hijack source located at `pwd` patched to version ${LASTPATCH}";
cd ..
